package com.nisum.demo.blobStorage;

import com.microsoft.azure.functions.annotation.*;
import com.microsoft.azure.functions.*;
import com.nisum.demo.blobStorage.pgp.PGPService;
import com.nisum.demo.blobStorage.pgp.PGPUtils;
import java.io.IOException;

import java.io.*;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;
import java.util.regex.Pattern;

/**
 * Azure Functions with Azure Blob trigger.
 */
public class BlobTriggerFunction {
    /**
     * This function will be invoked when a new or updated blob is detected at the specified path. The blob contents are provided as input to this function.
     */
    @FunctionName("BlobTriggerFunc")
    public void run(
            @BlobTrigger(name = "file", path = "test/{name}", dataType = "binary", connection = "AzureWebJobsStorage")
                    byte[] content,
            @BindingName("name") String name,
            final ExecutionContext context
    ) throws IOException {
        ResourceBundle resourceBundle = new PropertyResourceBundle(new FileInputStream(
                "/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/application.properties"));
        if (Pattern.matches("[a-z|A-Z]*.csv", name)) {
            String directoryPath = resourceBundle.getString("files.directory.path") + name;
            if (!Files.exists(Paths.get(directoryPath))) {
                Files.createFile(Paths.get(directoryPath));
            }

            try (FileOutputStream fileOutputStream = new FileOutputStream(directoryPath, true)) {
                fileOutputStream.write(content);
            }

            PGPService pgpService = new PGPService();
            pgpService.encryptFile(name);

            context.getLogger()
                    .info("Java Blob trigger function processed a blob. Name: " + name + "\n  Size: " + content.length +
                            " Bytes");
        }
    }
}
